@@ -3,6 +3,7 @@
 var assert = require("assert");
 var referee = require("../referee");
 
+// eslint-disable-next-line no-empty-function
 function noop() {}
 
 describe("assert.isFunction", function () {
@@ -38,9 +39,7 @@ describe("assert.isFunction", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isFunction] " +
-            message +
-            ": '[object Object]' ('object') expected to be function"
+          `[assert.isFunction] ${message}: '[object Object]' ('object') expected to be function`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isFunction");
@@ -83,9 +82,7 @@ describe("refute.isFunction", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isFunction] " +
-            message +
-            ": 'function noop() {}' expected not to be function"
+          `[refute.isFunction] ${message}: 'function noop() {}' expected not to be function`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isFunction");
