@@ -110,9 +110,7 @@ describe("assert.isInfinity", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInfinity] " +
-            message +
-            ": Expected -Infinity to be Infinity"
+          `[assert.isInfinity] ${message}: Expected -Infinity to be Infinity`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInfinity");
@@ -172,9 +170,7 @@ describe("refute.isInfinity", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isInfinity] " +
-            message +
-            ": Expected Infinity not to be Infinity"
+          `[refute.isInfinity] ${message}: Expected Infinity not to be Infinity`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isInfinity");
