@@ -1,6 +1,7 @@
 "use strict";
 
 var assert = require("assert");
+var inspect = require("util").inspect;
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
 
@@ -10,15 +11,17 @@ describe("assert.isInt8Array", function () {
   });
 
   it("should fail for Int16Array", function () {
+    const actual = new Int16Array(2);
+
     assert.throws(
       function () {
-        referee.assert.isInt8Array(new Int16Array(2));
+        referee.assert.isInt8Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt8Array] Expected Int16Array(2) [ 0, 0 ] to be an Int8Array"
+          `[assert.isInt8Array] Expected ${inspect(actual)} to be an Int8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt8Array");
@@ -28,15 +31,17 @@ describe("assert.isInt8Array", function () {
   });
 
   it("should fail for Int32Array", function () {
+    const actual = new Int32Array(2);
+
     assert.throws(
       function () {
-        referee.assert.isInt8Array(new Int32Array(2));
+        referee.assert.isInt8Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt8Array] Expected Int32Array(2) [ 0, 0 ] to be an Int8Array"
+          `[assert.isInt8Array] Expected ${inspect(actual)} to be an Int8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt8Array");
@@ -110,9 +115,7 @@ describe("assert.isInt8Array", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isInt8Array] " +
-            message +
-            ": Expected [Arguments] {} to be an Int8Array"
+          `[assert.isInt8Array] ${message}: Expected [Arguments] {} to be an Int8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isInt8Array");
@@ -124,15 +127,19 @@ describe("assert.isInt8Array", function () {
 
 describe("refute.isInt8Array", function () {
   it("should fail for Int8Array", function () {
+    const actual = new Int8Array(2);
+
     assert.throws(
       function () {
-        referee.refute.isInt8Array(new Int8Array(2));
+        referee.refute.isInt8Array(actual);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isInt8Array] Expected Int8Array(2) [ 0, 0 ] not to be an Int8Array"
+          `[refute.isInt8Array] Expected ${inspect(
+            actual
+          )} not to be an Int8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isInt8Array");
@@ -163,18 +170,19 @@ describe("refute.isInt8Array", function () {
 
   it("should fail with custom message", function () {
     var message = "dcd0c656-65a3-4117-8bd2-444b6e64d94c";
+    const actual = new Int8Array(2);
 
     assert.throws(
       function () {
-        referee.refute.isInt8Array(new Int8Array(2), message);
+        referee.refute.isInt8Array(actual, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isInt8Array] " +
-            message +
-            ": Expected Int8Array(2) [ 0, 0 ] not to be an Int8Array"
+          `[refute.isInt8Array] ${message}: Expected ${inspect(
+            actual
+          )} not to be an Int8Array`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isInt8Array");
