@@ -3,6 +3,7 @@
 var assert = require("assert");
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
+var inspect = require("util").inspect;
 
 describe("assert.isIntlDateTimeFormat", function () {
   it("should pass for Intl.DateTimeFormat", function () {
@@ -92,9 +93,7 @@ describe("assert.isIntlDateTimeFormat", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isIntlDateTimeFormat] " +
-            message +
-            ": Expected 'apple pie' to be an Intl.DateTimeFormat"
+          `[assert.isIntlDateTimeFormat] ${message}: Expected 'apple pie' to be an Intl.DateTimeFormat`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isIntlDateTimeFormat");
@@ -106,15 +105,19 @@ describe("assert.isIntlDateTimeFormat", function () {
 
 describe("refute.isIntlDateTimeFormat", function () {
   it("should fail for Intl.DateTimeFormat", function () {
+    var object = new Intl.DateTimeFormat();
+
     assert.throws(
       function () {
-        referee.refute.isIntlDateTimeFormat(new Intl.DateTimeFormat());
+        referee.refute.isIntlDateTimeFormat(object);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isIntlDateTimeFormat] Expected DateTimeFormat [Object] {} not to be an Intl.DateTimeFormat"
+          `[refute.isIntlDateTimeFormat] Expected ${inspect(
+            object
+          )} not to be an Intl.DateTimeFormat`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isIntlDateTimeFormat");
@@ -141,17 +144,19 @@ describe("refute.isIntlDateTimeFormat", function () {
 
   it("should fail with custom message", function () {
     var message = "c485cacd-b75c-4c2c-8903-c2e7f9b16766";
+    var object = new Intl.DateTimeFormat();
+
     assert.throws(
       function () {
-        referee.refute.isIntlDateTimeFormat(new Intl.DateTimeFormat(), message);
+        referee.refute.isIntlDateTimeFormat(object, message);
       },
       function (error) {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isIntlDateTimeFormat] " +
-            message +
-            ": Expected DateTimeFormat [Object] {} not to be an Intl.DateTimeFormat"
+          `[refute.isIntlDateTimeFormat] ${message}: Expected ${inspect(
+            object
+          )} not to be an Intl.DateTimeFormat`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isIntlDateTimeFormat");
