@@ -4,6 +4,7 @@ var assert = require("assert");
 var referee = require("../referee");
 var captureArgs = require("../test-helper/capture-args");
 
+// eslint-disable-next-line no-empty-function
 function noop() {}
 
 describe("assert.isNumber", function () {
@@ -128,9 +129,7 @@ describe("assert.isNumber", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isNumber] " +
-            message +
-            ": Expected NaN ('number') to be a non-NaN number"
+          `[assert.isNumber] ${message}: Expected NaN ('number') to be a non-NaN number`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isNumber");
@@ -262,9 +261,7 @@ describe("refute.isNumber", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isNumber] " +
-            message +
-            ": Expected 42 to be NaN or a non-number value"
+          `[refute.isNumber] ${message}: Expected 42 to be NaN or a non-number value`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isNumber");
