@@ -200,9 +200,7 @@ describe("assert.isRangeError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isRangeError] " +
-            message +
-            ": Expected Error to be a RangeError"
+          `[assert.isRangeError] ${message}: Expected Error to be a RangeError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isRangeError");
@@ -282,9 +280,7 @@ describe("refute.isRangeError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isRangeError] " +
-            message +
-            ": Expected RangeError not to be a RangeError"
+          `[refute.isRangeError] ${message}: Expected RangeError not to be a RangeError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isRangeError");
