@@ -92,9 +92,7 @@ describe("assert.isSymbol", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isSymbol] " +
-            message +
-            ": Expected 'apple pie' to be a Symbol"
+          `[assert.isSymbol] ${message}: Expected 'apple pie' to be a Symbol`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isSymbol");
@@ -134,9 +132,7 @@ describe("refute.isSymbol", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isSymbol] " +
-            message +
-            ": Expected Symbol(apple pie) not to be a Symbol"
+          `[refute.isSymbol] ${message}: Expected Symbol(apple pie) not to be a Symbol`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isSymbol");
