@@ -200,9 +200,7 @@ describe("assert.isSyntaxError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[assert.isSyntaxError] " +
-            message +
-            ": Expected Error to be a SyntaxError"
+          `[assert.isSyntaxError] ${message}: Expected Error to be a SyntaxError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "assert.isSyntaxError");
@@ -282,9 +280,7 @@ describe("refute.isSyntaxError", function () {
         assert.equal(error.code, "ERR_ASSERTION");
         assert.equal(
           error.message,
-          "[refute.isSyntaxError] " +
-            message +
-            ": Expected SyntaxError not to be a SyntaxError"
+          `[refute.isSyntaxError] ${message}: Expected SyntaxError not to be a SyntaxError`
         );
         assert.equal(error.name, "AssertionError");
         assert.equal(error.operator, "refute.isSyntaxError");
