@@ -3,13 +3,17 @@
 var samsam = require("@sinonjs/samsam");
 
 function createAsyncAssertion(thenFunc, catchFunc) {
-  function asyncAssertion(promise, expected) {
+  function asyncAssertion(promise) {
     var self = this;
-    this.expected = arguments.length === 1 ? samsam.match.any : expected;
+    this.expected = arguments.length === 1 ? samsam.match.any : arguments[1];
     function applyCallback(callback, context) {
       return function (actual) {
         self.actual = actual;
-        callback.apply(context, [actual, self.expected]);
+        try {
+          callback.apply(context, [actual, self.expected]);
+        } catch (error) {
+          context.reject(error.message);
+        }
       };
     }
     var assertionPromise = new Promise(function (resolve, reject) {
